==> DynareR_0.1.1.tar.gz: DynareR/inst/doc/DynareR.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval=F,
  echo = T
  
)

## ----setup1, include=FALSE----------------------------------------------------
#  library(DynareR)

## ----installation,eval=FALSE--------------------------------------------------
#  install.packages("DynareR")
#  
#            OR
#  
#  devtools::install_github('sagirumati/DynareR')

## ----includeIRF---------------------------------------------------------------
#  include_IRF(model="",IRF="",path="")

## ----dyn----------------------------------------------------------------------
#  write_dyn(model, code, path = "")
#  

## ----exampleDyn---------------------------------------------------------------
#  DynareCodes='var y, c, k, a, h, b;
#  varexo e, u;
#  parameters beta, rho, alpha, delta, theta, psi, tau;
#  alpha = 0.36;
#  rho   = 0.95;
#  tau   = 0.025;
#  beta  = 0.99;
#  delta = 0.025;
#  psi   = 0;
#  theta = 2.95;
#  phi   = 0.1;
#  model;
#  c*theta*h^(1+psi)=(1-alpha)*y;
#  k = beta*(((exp(b)*c)/(exp(b(+1))*c(+1)))
#            *(exp(b(+1))*alpha*y(+1)+(1-delta)*k));
#  y = exp(a)*(k(-1)^alpha)*(h^(1-alpha));
#  k = exp(b)*(y-c)+(1-delta)*k(-1);
#  a = rho*a(-1)+tau*b(-1) + e;
#  b = tau*a(-1)+rho*b(-1) + u;
#  end;
#  initval;
#  y = 1.08068253095672;
#  c = 0.80359242014163;
#  h = 0.29175631001732;
#  k = 11.08360443260358;
#  a = 0;
#  b = 0;
#  e = 0;
#  u = 0;
#  end;
#  
#  shocks;
#  var e; stderr 0.009;
#  var u; stderr 0.009;
#  var e, u = phi*0.009*0.009;
#  end;
#  
#  stoch_simul;'
#  
#  model<-"example1"
#  code<-DynareCodes
#  
#  write_dyn(model,code)

## ----mod----------------------------------------------------------------------
#  write_mod(model, code, path = "")
#  

## ----examplemod---------------------------------------------------------------
#  DynareCodes='var y, c, k, a, h, b;
#  varexo e, u;
#  parameters beta, rho, alpha, delta, theta, psi, tau;
#  alpha = 0.36;
#  rho   = 0.95;
#  tau   = 0.025;
#  beta  = 0.99;
#  delta = 0.025;
#  psi   = 0;
#  theta = 2.95;
#  phi   = 0.1;
#  model;
#  c*theta*h^(1+psi)=(1-alpha)*y;
#  k = beta*(((exp(b)*c)/(exp(b(+1))*c(+1)))
#            *(exp(b(+1))*alpha*y(+1)+(1-delta)*k));
#  y = exp(a)*(k(-1)^alpha)*(h^(1-alpha));
#  k = exp(b)*(y-c)+(1-delta)*k(-1);
#  a = rho*a(-1)+tau*b(-1) + e;
#  b = tau*a(-1)+rho*b(-1) + u;
#  end;
#  initval;
#  y = 1.08068253095672;
#  c = 0.80359242014163;
#  h = 0.29175631001732;
#  k = 11.08360443260358;
#  a = 0;
#  b = 0;
#  e = 0;
#  u = 0;
#  end;
#  
#  shocks;
#  var e; stderr 0.009;
#  var u; stderr 0.009;
#  var e, u = phi*0.009*0.009;
#  end;
#  
#  stoch_simul;'
#  
#  model<-"example1"
#  code<-DynareCodes
#  
#  write_mod(model,code)

## ----runDynare----------------------------------------------------------------
#  run_dynare(model,code,path)
#  

## ----exampleRunDynare---------------------------------------------------------
#  DynareCodes='var y, c, k, a, h, b;
#  varexo e, u;
#  parameters beta, rho, alpha, delta, theta, psi, tau;
#  alpha = 0.36;
#  rho   = 0.95;
#  tau   = 0.025;
#  beta  = 0.99;
#  delta = 0.025;
#  psi   = 0;
#  theta = 2.95;
#  phi   = 0.1;
#  model;
#  c*theta*h^(1+psi)=(1-alpha)*y;
#  k = beta*(((exp(b)*c)/(exp(b(+1))*c(+1)))
#            *(exp(b(+1))*alpha*y(+1)+(1-delta)*k));
#  y = exp(a)*(k(-1)^alpha)*(h^(1-alpha));
#  k = exp(b)*(y-c)+(1-delta)*k(-1);
#  a = rho*a(-1)+tau*b(-1) + e;
#  b = tau*a(-1)+rho*b(-1) + u;
#  end;
#  initval;
#  y = 1.08068253095672;
#  c = 0.80359242014163;
#  h = 0.29175631001732;
#  k = 11.08360443260358;
#  a = 0;
#  b = 0;
#  e = 0;
#  u = 0;
#  end;
#  
#  shocks;
#  var e; stderr 0.009;
#  var u; stderr 0.009;
#  var e, u = phi*0.009*0.009;
#  end;
#  
#  stoch_simul;'
#  
#  model<-"example1"
#  code<-DynareCodes
#  
#  run_dynare(model,code)
#  

## ----runModels----------------------------------------------------------------
#  run_models(model, path = "")
#  

## ----exampleRunModels---------------------------------------------------------
#  model=c("example1","example2","agtrend","bkk")
#  run_models(model)
#  
#

==> DynareR_0.1.2.tar.gz: DynareR/inst/doc/DynareR.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval=F,
  echo = T
  
)

## ----setup1, include=FALSE----------------------------------------------------
#  library(DynareR)

## ----installation,eval=FALSE--------------------------------------------------
#  install.packages("DynareR")
#  
#            OR
#  
#  devtools::install_github('sagirumati/DynareR')

## ----includeIRF---------------------------------------------------------------
#  include_IRF(model="",IRF="",path=".")

## ----dyn----------------------------------------------------------------------
#  write_dyn(model, code, path = ".")
#  

## ----exampleDyn---------------------------------------------------------------
#  DynareCodes='var y, c, k, a, h, b;
#  varexo e, u;
#  parameters beta, rho, alpha, delta, theta, psi, tau;
#  alpha = 0.36;
#  rho   = 0.95;
#  tau   = 0.025;
#  beta  = 0.99;
#  delta = 0.025;
#  psi   = 0;
#  theta = 2.95;
#  phi   = 0.1;
#  model;
#  c*theta*h^(1+psi)=(1-alpha)*y;
#  k = beta*(((exp(b)*c)/(exp(b(+1))*c(+1)))
#            *(exp(b(+1))*alpha*y(+1)+(1-delta)*k));
#  y = exp(a)*(k(-1)^alpha)*(h^(1-alpha));
#  k = exp(b)*(y-c)+(1-delta)*k(-1);
#  a = rho*a(-1)+tau*b(-1) + e;
#  b = tau*a(-1)+rho*b(-1) + u;
#  end;
#  initval;
#  y = 1.08068253095672;
#  c = 0.80359242014163;
#  h = 0.29175631001732;
#  k = 11.08360443260358;
#  a = 0;
#  b = 0;
#  e = 0;
#  u = 0;
#  end;
#  
#  shocks;
#  var e; stderr 0.009;
#  var u; stderr 0.009;
#  var e, u = phi*0.009*0.009;
#  end;
#  
#  stoch_simul;'
#  
#  model<-"example1"
#  code<-DynareCodes
#  
#  write_dyn(model,code)

## ----mod----------------------------------------------------------------------
#  write_mod(model, code, path = ".")
#  

## ----examplemod---------------------------------------------------------------
#  DynareCodes='var y, c, k, a, h, b;
#  varexo e, u;
#  parameters beta, rho, alpha, delta, theta, psi, tau;
#  alpha = 0.36;
#  rho   = 0.95;
#  tau   = 0.025;
#  beta  = 0.99;
#  delta = 0.025;
#  psi   = 0;
#  theta = 2.95;
#  phi   = 0.1;
#  model;
#  c*theta*h^(1+psi)=(1-alpha)*y;
#  k = beta*(((exp(b)*c)/(exp(b(+1))*c(+1)))
#            *(exp(b(+1))*alpha*y(+1)+(1-delta)*k));
#  y = exp(a)*(k(-1)^alpha)*(h^(1-alpha));
#  k = exp(b)*(y-c)+(1-delta)*k(-1);
#  a = rho*a(-1)+tau*b(-1) + e;
#  b = tau*a(-1)+rho*b(-1) + u;
#  end;
#  initval;
#  y = 1.08068253095672;
#  c = 0.80359242014163;
#  h = 0.29175631001732;
#  k = 11.08360443260358;
#  a = 0;
#  b = 0;
#  e = 0;
#  u = 0;
#  end;
#  
#  shocks;
#  var e; stderr 0.009;
#  var u; stderr 0.009;
#  var e, u = phi*0.009*0.009;
#  end;
#  
#  stoch_simul;'
#  
#  model<-"example1"
#  code<-DynareCodes
#  
#  write_mod(model,code)

## ----runDynare----------------------------------------------------------------
#  run_dynare(model,code,path)
#  

## ----exampleRunDynare---------------------------------------------------------
#  DynareCodes='var y, c, k, a, h, b;
#  varexo e, u;
#  parameters beta, rho, alpha, delta, theta, psi, tau;
#  alpha = 0.36;
#  rho   = 0.95;
#  tau   = 0.025;
#  beta  = 0.99;
#  delta = 0.025;
#  psi   = 0;
#  theta = 2.95;
#  phi   = 0.1;
#  model;
#  c*theta*h^(1+psi)=(1-alpha)*y;
#  k = beta*(((exp(b)*c)/(exp(b(+1))*c(+1)))
#            *(exp(b(+1))*alpha*y(+1)+(1-delta)*k));
#  y = exp(a)*(k(-1)^alpha)*(h^(1-alpha));
#  k = exp(b)*(y-c)+(1-delta)*k(-1);
#  a = rho*a(-1)+tau*b(-1) + e;
#  b = tau*a(-1)+rho*b(-1) + u;
#  end;
#  initval;
#  y = 1.08068253095672;
#  c = 0.80359242014163;
#  h = 0.29175631001732;
#  k = 11.08360443260358;
#  a = 0;
#  b = 0;
#  e = 0;
#  u = 0;
#  end;
#  
#  shocks;
#  var e; stderr 0.009;
#  var u; stderr 0.009;
#  var e, u = phi*0.009*0.009;
#  end;
#  
#  stoch_simul;'
#  
#  model<-"example1"
#  code<-DynareCodes
#  
#  run_dynare(model,code)
#  

## ----runModels----------------------------------------------------------------
#  run_models(model, path = ".")
#  

## ----exampleRunModels---------------------------------------------------------
#  
#  run_models(model=c("example1","example2","agtrend","bkk"))
#  

## ----runAllDynare-------------------------------------------------------------
#  run_models()
#  

## ----runAllDynare1------------------------------------------------------------
#  run_models(path = 'DynareR/run_models')
#
